<?php
/**
 * Slider options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */
// Add slider section
$wp_customize->add_section( 'yummy_pro_slider_section', array(
	'title'             => esc_html__( 'Slider Section','yummy-pro' ),
	'description'       => esc_html__( 'Slider options.', 'yummy-pro' ),
	'panel'             => 'yummy_pro_sections_panel',
) );
/**
 * Slider Options
 */
// Enable slider.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_slider]', array(
	'default'           => $options['enable_slider'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_slider]', array(
	'label'             => esc_html__( 'Enable Slider', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'type'				=> 'checkbox'
) );

// Transition type.
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_transition]', array(
	'default'           => $options['slider_transition'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[slider_transition]', array(
	'active_callback'	=> 'yummy_pro_is_slider_enable',
	'label'             => esc_html__( 'Transition Effects', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'choices'			=> yummy_pro_transition_effects_options(),
	'type'				=> 'select'
) );

// Slider speed.
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_speed]', array(
	'default'           => $options['slider_speed'],
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[slider_speed]', array(
	'active_callback'	=> 'yummy_pro_is_slider_enable',
	'label'             => esc_html__( 'Slider Speed ( in milliseconds )', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'input_attrs'		=> array( 'min' => 1 ),
	'type'				=> 'number'
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_slider_pager]', array(
	'default'           => $options['enable_slider_pager'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_slider_pager]', array(
	'active_callback' => 'yummy_pro_is_slider_enable',
	'label'           => esc_html__( 'Enable Pager Controls?', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'            => 'checkbox',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_slider_arrows]', array(
	'default'           => $options['enable_slider_arrows'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_slider_arrows]', array(
	'active_callback' => 'yummy_pro_is_slider_enable',
	'label'           => esc_html__( 'Enable Arrows Controls?', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'            => 'checkbox',
) );

// Add enable slider autoplay setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_slider_autoplay]', array(
	'default'           => $options['enable_slider_autoplay'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_slider_autoplay]', array(
	'active_callback' => 'yummy_pro_is_slider_enable',
	'label'           => esc_html__( 'Enable Autoplay?', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'            => 'checkbox',
) );

// Make slider draggable setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[make_slider_draggable]', array(
	'default'           => $options['make_slider_draggable'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'yummy_pro_theme_options[make_slider_draggable]', array(
	'active_callback' => 'yummy_pro_is_slider_enable',
	'label'           => esc_html__( 'Make slider draggable?', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'            => 'checkbox',
) );

// Slider Loop setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_infinite_sliding]', array(
	'default'           => $options['enable_infinite_sliding'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_infinite_sliding]', array(
	'active_callback' => 'yummy_pro_is_slider_enable',
	'label'           => esc_html__( 'Enable infinite sliding?', 'yummy-pro' ),
	'description'     => esc_html__( 'Checking this will let the slider to slide from last to first.', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'            => 'checkbox',
) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_basic_controls]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[slider_basic_controls]',
	array(
		'active_callback' => 'yummy_pro_is_slider_enable',
		'section'         => 'yummy_pro_slider_section',
		'type'			  => 'hr',
) ) );

// enable slider logo.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_slider_logo]', array(
	'default'           => $options['enable_slider_logo'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_slider_logo]', array(
	'active_callback'	=> 'yummy_pro_is_slider_enable',
	'label'             => esc_html__( 'Enable Slider Logo', 'yummy-pro' ),
	'description'		=> esc_html__( 'Note: Custom logo is set as slider logo for content type post, page and category.','yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'type'				=> 'checkbox',
) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_basic_controls]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[slider_basic_controls]',
	array(
		'active_callback' => 'yummy_pro_is_slider_enable',
		'section'         => 'yummy_pro_slider_section',
		'type'			  => 'hr',
) ) );

/**
 * Slider content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_content_type]', array(
	'default'           => $options['slider_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[slider_content_type]', array(
	'active_callback'	=> 'yummy_pro_is_slider_enable',
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'choices'			=> yummy_pro_slider_content_type_options(),
	'type'				=> 'select'
) );

// Number of slider.
$wp_customize->add_setting( 'yummy_pro_theme_options[number_of_slider]', array(
	'default'           => $options['number_of_slider'],
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
	'validate_callback' => 'yummy_pro_validate_slider_count',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[number_of_slider]', array(
	'active_callback'	=> 'yummy_pro_is_slider_demo_disable',
	'label'             => esc_html__( 'Number of sliders? ( Max: 5 )', 'yummy-pro' ),
	'description'       => esc_html__( 'Note: Please refresh after changing the value to see the changes.', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'input_attrs'		=> array( 'min' => 1, 'max' => 5 ),
	'type'				=> 'number'
) );

/**
 * Post Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_post_ids]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[slider_post_ids]', array(
	'active_callback'	=> 'yummy_pro_is_slider_content_type_post_enable',
	'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. posts allowed is handle from number of slider options. Input value as: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_slider_section',
	'type'				=> 'text'
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[slider_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[slider_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_slider_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_slider_content_type_category_enable',
) ) );

for ( $i=1; $i <= $options['number_of_slider']; $i++ ) { 
	
	/**
	 * Page Content Type Options
	 */
	// Page Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[slider_page_'.$i.']', array(
		'sanitize_callback' => 'yummy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[slider_page_'.$i.']', array(
		'active_callback' => 'yummy_pro_is_slider_content_type_page_enable',
		'label'           => esc_html__( 'Select Page ', 'yummy-pro' ) . $i,
		'section'         => 'yummy_pro_slider_section',
		'type'            => 'dropdown-pages',
	) );

	/**
	 * Slider logo image setting and control
	 */
	$wp_customize->add_setting( 'yummy_pro_theme_options[slider_logo_image'.$i.']', array(
		'default'           => $options['slider_logo_image'],
		'sanitize_callback' => 'yummy_pro_sanitize_image',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[slider_logo_image'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Slider Logo Image %s', 'yummy-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 550, 175 ),
			'section'     		=> 'yummy_pro_slider_section',
			'active_callback'	=> 'yummy_pro_is_slider_demo_disable',
	) ) );
}