<?php
/**
 * Special Item options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */
// Add Special Item section
$wp_customize->add_section( 'yummy_pro_special_item_section', array(
	'title'             => esc_html__( 'Special Items Section','yummy-pro' ),
	'description'       => esc_html__( 'Special Items options.', 'yummy-pro' ),
	'panel'             => 'yummy_pro_sections_panel',
) );
/**
 * Special Item Options
 */
// Enable Special Item.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_special_item]', array(
	'default'           => $options['enable_special_item'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_special_item]', array(
	'label'             => esc_html__( 'Enable Special Item Section', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'checkbox'
) );

/**
 * Special Item Header Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[special_item_header_label]', array(
	'label'           	=> esc_html__( 'Header Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_item_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_special_item_section_active',
) ) );

/**
 * Special Item Header type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_type]', array(
	'default'           => $options['special_item_header_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_header_type]', array(
	'active_callback'	=> 'yummy_pro_is_special_item_section_active',
	'label'             => esc_html__( 'Header Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'choices'			=> yummy_pro_special_item_header_type_options(),
	'type'				=> 'select'
) );

/**
 * Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_title]', array(
	'default'           => $options['special_item_header_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_header_title]', array(
	'active_callback'	=> 'yummy_pro_special_item_header_custom',
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[special_item_header_title]', array(
		'selector'            => '#parallax-1 .wrapper .entry-header h2.entry-title a',
		'settings'            => 'yummy_pro_theme_options[special_item_header_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_special_item_header_title',
    ) );
}

/**
 * Title link Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_header_link]', array(
	'active_callback'	=> 'yummy_pro_special_item_header_custom',
	'label'             => esc_html__( 'Title Link', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'url'
) );

/**
 * Special Item image setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_image]', array(
	'default'           => $options['special_item_header_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[special_item_header_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_special_item_section',
		'active_callback'	=> 'yummy_pro_special_item_header_custom',
) ) );

/**
 * Special Item Header page Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_header_page]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_header_page]', array(
	'active_callback'	=> 'yummy_pro_special_item_header_page',
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'description'       => esc_html__( 'Info: Make sure selected page has featured image.', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'dropdown-pages'
) );

/**
 * Special Item hr setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[special_item_hr]',
	array(
		'section'         => 'yummy_pro_special_item_section',
		'active_callback' => 'yummy_pro_is_special_item_section_active',
		'type'			  => 'hr'
) ) );

/**
 * Special Item Content Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[special_item_content_label]', array(
	'label'           	=> esc_html__( 'Content Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_item_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_special_item_section_active',
) ) );

/**
 * Special Item content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_type]', array(
	'default'           => $options['special_item_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_content_type]', array(
	'active_callback'	=> 'yummy_pro_is_special_item_section_active',
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'choices'			=> yummy_pro_special_item_content_type_options(),
	'type'				=> 'select'
) );


/**
 * No of Contents Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_count]', array(
	'default'			=> $options['special_item_content_count'],
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
	'validate_callback' => 'yummy_pro_validate_special_item_count',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_content_count]', array(
	'active_callback'	=> 'yummy_pro_special_item_content_count',
	'label'             => esc_html__( 'No. of Posts', 'yummy-pro' ),
	'description'       => esc_html__( 'Max posts: 6', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style'	=> 'width:100px',
		),
) );


/**
 * Post Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_post]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_content_post]', array(
	'active_callback'	=> 'yummy_pro_special_item_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. posts allowed is 6. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'text'
) );


/**
 * Category Content Type Options
 */
// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[special_item_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_special_item_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_special_item_content_category',
) ) );


/**
 * Woocommerce Product Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_woo_product]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_item_content_woo_product]', array(
	'active_callback'	=> 'yummy_pro_special_item_content_woo_product',
	'label'             => esc_html__( 'Input WooCommerce Product Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. products allowed is 6. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_item_section',
	'type'				=> 'text'
) );


/**
 * Woocommerce Product Category Content Type Options
 */
// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[special_item_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[special_item_content_woo_category]', array(
	'label'           	=> esc_html__( 'Select WooCommerce Product Category', 'yummy-pro' ),
	'description'     	=> esc_html__( 'Latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_item_section',
	'taxonomy'		  	=> 'product_cat',
	'type'			  	=> 'dropdown-category',
	'active_callback' 	=> 'yummy_pro_special_item_content_woo_category',
) ) );