<?php 
/**
 * Special Day section
 *
 * This is the template for the content of Special Day section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_special_day_section' ) ) :
    /**
    * Add Special Day section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_special_day_section() {
        // Check if Special Day is enabled
        $enable_special_day = apply_filters( 'yummy_pro_section_status', true, 'enable_special_day' );

        if ( true !== $enable_special_day ) {
            return false;
        }

        // Get Special Day section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_special_day_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Special Day section now.
        yummy_pro_render_special_day_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_special_day_section', 80 );


if ( ! function_exists( 'yummy_pro_get_special_day_section_details' ) ) :
    /**
    * Special Day section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input Special Day section details.
    */
    function yummy_pro_get_special_day_section_details( $input ) {
        $options = yummy_pro_get_theme_options();

        // Special Day type
        $special_day_left_type          = $options['special_day_left_type'];
        $special_day_right_note_type    = $options['special_day_right_note_type'];
        $special_day_right_type         = $options['special_day_right_type'];

        $content = array();

        // left section
        switch ( $special_day_left_type ) {

            case 'demo':
                $content['left'][0]['title']      = sprintf( esc_html__( '%1$sRock%2$s %3$sFriday%4$s %5$sWe cook special in%6$s %7$sSpecial day%8$s', 'yummy-pro' ), '<h2>', '</h2>', '<span>', '</span>', '<p>', '</p>', '<h3>', '</h3>'  );
                $content['left'][0]['btn_label']  = esc_html__( 'Reservation', 'yummy-pro' );
                $content['left'][0]['btn_url']    = '#';
            break;

            case 'custom':
                $content['left'][0]['title']      = ! empty( $options['special_day_left_note'] ) ? $options['special_day_left_note'] : '';
                $content['left'][0]['btn_label']  = ! empty( $options['special_day_left_btn_title'] ) ? $options['special_day_left_btn_title'] : '';
                $content['left'][0]['btn_url']    = ! empty( $options['special_day_left_btn_link'] ) ? $options['special_day_left_btn_link'] : '#';
            break;
            
        }

        // right note section
        switch ( $special_day_right_note_type ) {

            case 'demo':
                $content['right_note'][0]['title']      = esc_html__( 'Hi&#44; Today is Rock Friday', 'yummy-pro' );
                $content['right_note'][0]['excerpt']    = sprintf( esc_html__( '%1$sPellentesque aliquam felis id justo efficitur, eu commodo sem vestibulum. Morbi vulputate tortor nec est mollis, et dignissim nisi malesuada. Ut et ornare lectus. Accumsan sapien, eget venenatis velit dolor eu est.%2$s %1$sCras at lacus eros. Donec vitae nibh finibus, faucibus felis auctor, varius arcu.%2$s', 'yummy-pro' ), '<p>', '</p>' );
            break;

            case 'custom':
                $content['right_note'][0]['title']      = ! empty( $options['special_day_right_note_title'] ) ? $options['special_day_right_note_title'] : '';
                $content['right_note'][0]['excerpt']    = ! empty( $options['special_day_right_note_description'] ) ? $options['special_day_right_note_description'] : '';
            break;

            case 'post':
                $id = '';
                
                if ( ! empty( $options['special_day_right_note_post'] ) )
                    $id = absint( $options['special_day_right_note_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $id ) ) {
                    return $input;
                }

                $post = get_post( $id );
                $content['right_note'][0]['title']      = $post->post_title;
                $content['right_note'][0]['excerpt']    = $post->post_content;

            break;

            case 'page':
                $id = '';
                
                if ( ! empty( $options['special_day_right_note_page'] ) )
                    $id = absint( $options['special_day_right_note_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $id ) ) {
                    return $input;
                }
                $post = get_post( $id );
                $content['right_note'][0]['title']      = $post->post_title;
                $content['right_note'][0]['excerpt']    = $post->post_content;

            break;
        }


        // right content section 
        switch ( $special_day_right_type ) {
          	case 'demo':
                $title = array( esc_html__( 'Fish Cake', 'yummy-pro' ), esc_html__( 'Chicken Chilly', 'yummy-pro' ), esc_html__( 'French Salad', 'yummy-pro' ), esc_html__( 'Club Sandwich','yummy-pro' ) );
                for ( $i = 0; $i <= 3; $i++ ) {
                    $content['content'][$i]['title']    = $title[$i]; 
                    $content['content'][$i]['url']      = '#'; 
                    if ( $i < 1 ) :
                        $content['content'][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/friday.jpg'; 
                    else :
                        $content['content'][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/recent-product-0' . $i . '.jpg';
                    endif;
                    $content['content'][$i]['img_array'][1] = 200;
                    $content['content'][$i]['img_array'][2] = 200;
                }
          	break;     

          	case 'post':
                $ids = array();
                
                if ( ! empty( $options['special_day_content_post'] ) )
                    $ids = ( array ) $options['special_day_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 10,
                );                  
            break;

            case 'category':
                $cat_id = '';

                if ( ! empty( $options['special_day_content_category'] ) )
                    $cat_id = $options['special_day_content_category'];

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }

                $args = array(
                  'no_found_rows'  => true,
                  'cat'            => $cat_id,
                  'post_type'      => 'post',
                  'posts_per_page' => absint( $options['special_day_right_count'] ),
                );
            break;

            case 'woo-product':
                $ids = array();
                
                if ( ! empty( $options['special_day_content_woo_product'] ) )
                    $ids = ( array ) $options['special_day_content_woo_product'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'product',
                    'post__in'       => $ids,
                    'posts_per_page' => 10,
                );      

            break;

            case 'woo-category':
                $cat_id = '';

                if ( ! empty( $options['special_day_content_woo_category'] ) )
                    $cat_id = $options['special_day_content_woo_category'];

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $options['special_day_right_count'] ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

        }

        if ( 'demo' != $special_day_right_type ) {
            $posts = get_posts( $args );
            $i = 1;
            foreach ( $posts as $post ) :
                $page_id = $post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    if ( $i == 1 ) 
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'medium_large' );
                    else
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'thumbnail' );
                } else {
                    $img_array[0]  = get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
                    $img_array[1]  = 300;
                    $img_array[2]  = 300;
                }
                $content['content'][$i]['id']           = $page_id;
                $content['content'][$i]['title']        = get_the_title( $page_id );
                $content['content'][$i]['url']          = get_the_permalink( $page_id );
                $content['content'][$i]['img_array']    = $img_array;
                $i++;
            endforeach;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Special Day section content details.
add_filter( 'yummy_pro_filter_special_day_section_details', 'yummy_pro_get_special_day_section_details' );


if ( ! function_exists( 'yummy_pro_render_special_day_section' ) ) :
    /**
    * Start Special Day section
    *
    * @return string Special Day content
    * @since Yummy Pro 1.0
    *
    */
    function yummy_pro_render_special_day_section( $content_details = array() ) {
        $options = yummy_pro_get_theme_options();
        $background_img = ! empty( $options['special_day_background_image'] ) ? $options['special_day_background_image'] : get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';

        if ( empty( $content_details ) ) {
          return;
        } 
        ?>
        <section id="rock-friday" class="parallax" style="background-image:url('<?php echo esc_url( $background_img ); ?>');"  data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="wrapper">
                <div class="row">
                    <div class="special-day col-2">
                        <?php if ( ! empty( $content_details['left'] ) ) : 
                            foreach ( $content_details['left'] as $content_detail ) : ?>
                                <div class="column-wrapper">
                                    <div class="friday-organize">
                                        <?php 
                                        if ( ! empty( $content_detail['title'] ) ) :
                                            echo wp_kses_post( $content_detail['title'] ); 
                                        endif; 
                                        if ( ! empty( $content_detail['btn_label'] ) ) :
                                        ?>
                                            <a href="<?php echo esc_url( $content_detail['btn_url'] ); ?>" class="btn btn-transparent"><?php echo esc_html( $content_detail['btn_label'] ); ?></a>
                                        <?php endif; ?>
                                    </div><!--.fiday-organize-->
                                </div><!--.column-wrapper-->
                        <?php endforeach;
                        endif; ?>


                        <div class="column-wrapper">
                            <div class="friday-special clear col-2">
                                <?php if ( ! empty( $content_details['content'] ) ) : 
                                    $i = 1;
                                    foreach ( $content_details['content'] as $content_detail ) : ?>
                                        <div class="column-wrapper">
                                            <div style="background-image:url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');">
                                                <div class="special-item">
                                                    <h4><?php echo esc_html( $content_detail['title'] ); ?></h4>
                                                </div><!--.special-item-->
                                            </div><!--/div-->
                                        </div><!--.column-wrapper-->
                                    <?php if ( $i == 1 ) break;
                                    endforeach;
                                endif; ?>

                                <div class="column-wrapper">
                                    <div class="special-event">
                                        <?php if ( ! empty( $content_details['right_note'] ) ) : 
                                            foreach ( $content_details['right_note'] as $content_detail ) :?>
                                                <div class="today-special">
                                                    <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                                        <h2><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                                    <?php endif; ?>
                                                    <span><?php esc_html_e( 'Special', 'yummy-pro' ); ?></span>
                                                    <?php if ( ! empty( $content_detail['excerpt'] ) ) :
                                                        echo '<p>' . wp_kses_post( $content_detail['excerpt'] ) . '</p>';
                                                    endif; ?>
                                                </div><!--.today-special-->
                                            <?php endforeach;
                                        endif; ?>

                                        <?php if ( ! empty( $content_details['content'] ) ) : ?>
                                            <div class="slider regular" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": true, "speed": 600, "dots": false, "arrows":true, "autoplay": true, "fade": false, "dragable":false}'>
                                                <?php $i = 1;
                                                foreach ( $content_details['content'] as $content_detail ) : 
                                                    if ( $i > 1 ) : ?>
                                                    <div class="slick-item">
                                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                                            <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>">
                                                        </a>
                                                        <h5><?php echo esc_html( $content_detail['title'] ); ?></h5>
                                                    </div>
                                                <?php endif;
                                                $i++; endforeach; ?>
                                            </div><!--.slider-->
                                        <?php endif; ?>
                                    </div><!--.special-event-->
                                </div><!--.column-wrapper-->
                            </div><!--.friday-special-->
                        </div><!--.column-wrapper-->
                    </div><!--.special-day-->
                </div><!--.row-->
            </div><!--.wrapper-->
        </section><!--#rock-friday-->
    <?php    
    }
endif;