<?php
/**
 * yummy_pro custom template helper functions
 *
 * This is the template that includes all the other hooks of custom templates.
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_ajax_enqueuer' ) ) :
	/**
	 * ajax enquue
	 *
	 * @since Yummy Pro 1.0
	 */
	function yummy_pro_ajax_enqueuer() {

		$categories_id = get_post_meta( get_the_id(), 'yummy-pro-gallery-template', true );
	   	wp_register_script( "yummy-pro-ajax", get_template_directory_uri() . '/assets/js/ajax.min.js', array('jquery') );
	   	wp_localize_script( 'yummy-pro-ajax', 'yummy_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'category' => $categories_id ) );        
	   	wp_enqueue_script( 'yummy-pro-ajax' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'yummy_pro_ajax_enqueuer' );

if ( ! function_exists( 'yummy_pro_gallery_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Yummy Pro 1.0
	 */
	function yummy_pro_gallery_ajax_handler(){
		
		$gallery_ids = ( isset( $_POST['category'] ) ) ? array_map( 'absint', wp_unslash( $_POST['category'] ) ) : array();

	    $page = ( isset( $_POST['pageNumber'] ) ) ? absint( wp_unslash( $_POST['pageNumber'] ) ) : 1;
	    header("Content-Type: text/html");

	    $gallery_args = array(
	        'post_type' 		=> 'post',
	        'posts_per_page' 	=> absint( get_option( 'posts_per_page', 9 ) ),
	        'category__in'      => $gallery_ids,
	        'paged'    			=> $page,
	    );

        $gallery_posts = get_posts( $gallery_args );
        if( !empty( $gallery_posts ) ) :
            
            $index = 1;

            foreach ( $gallery_posts as $key => $gallery_post ) {
                if( ( $index == 2 ) || ( $index == 8 ) ) {
                    $item = 2;
                }
                elseif( $index == 7 ) {
                    $item = 3;
                }
                elseif( $index == 9 ) {
                	$item = 1;
                	$index = 1;
                } else{
                	$item = 1;
                }

                $gallery_post_id = $gallery_post->ID;
                $img_array = array();
                if ( has_post_thumbnail( $gallery_post_id ) ) {
                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_post->ID ), 'medium_large' );
                    $img_array[0] = $featured_img[0];
                } else {
                    $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                }
                if ( isset( $img_array ) ) {
                  $post_image['img_array'] = $img_array[0];
                }
                $post_title        = get_the_title( $gallery_post_id );
                $post_url          = get_the_permalink( $gallery_post_id ); 
                $post_categories   = get_the_category( $gallery_post_id );

                $post_category_list = '';
                $post_category_name = '';
                foreach ( $post_categories as $key => $post_category ) {
                    $post_category_name .= $post_category->name . ' ';
                    $post_category_list .= $post_category->slug . ' ';
                } ?>
                
                <div class="portfolio-item item-w<?php echo esc_attr( $item ); ?> <?php echo esc_attr( $post_category_list ); ?>">
                	<div class="portfolio-featured-image" style="background-image:url('<?php echo esc_url( $post_image['img_array'] ); ?>');">
	                  	<div class="black-overlay"></div>
	                  	<div class="portfolio-hover">
	                    	<h4><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></h4>
	                    	<div class="portfolio-icons">
	                      		<a href="<?php echo esc_url( $post_url ); ?>"><i class="fa fa-link"></i></a>
	                      		<a href="<?php echo esc_url( $post_image['img_array'][0] ); ?>" class="popup"><i class="fa fa-eye"></i></a>
	                    	</div><!-- .portfolio-icons -->
	                  	</div><!-- .portfolio-hover -->       
                	</div><!-- .portfolio-featured-image -->
              	</div><!-- .portfolio-item -->
            <?php $index++;
        	}
        endif; 
	    die();
	}
endif;
add_action("wp_ajax_yummy_pro_gallery_ajax_handler", "yummy_pro_gallery_ajax_handler");
add_action("wp_ajax_nopriv_yummy_pro_gallery_ajax_handler", "yummy_pro_gallery_ajax_handler");

if ( ! function_exists( 'yummy_pro_about_us_main_slider' ) ) :
	/**
	 * Check about us template slider
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_about_us_main_slider() {

		$options = yummy_pro_get_theme_options(); 
		$about_us_content_type = $options['about_us_content_type'];

		switch ( $about_us_content_type ) {
          	
          	case 'page':
                $about_slider_ids = array();
                for ( $i = 1; $i <= $options['number_of_about_slider']; $i++ ) {
                    $about_slider_id = null;
                    if ( isset( $options[ 'about_us_slider_page_'.$i ] ) ) {
                        $about_slider_id = $options[ 'about_us_slider_page_'.$i ];
                    }
                    if ( ! empty( $about_slider_id ) ) {
                        $about_slider_ids[] = absint( $about_slider_id );
                    }
                }
                if( empty( $about_slider_ids ) ) {
		        	return;
		        }
                $about_slider_args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $about_slider_ids,
                );
            break;

            case 'post':
                $about_slider_ids = array();

				if ( ! empty( $options[ 'about_us_slider_posts' ] ) ) {
                    $about_slider_ids = ( array ) $options[ 'about_us_slider_posts' ];
                }
                // Bail if no valid pages are selected.
		        if( empty( $about_slider_ids ) ) {
		        	return;
		        }
                $about_slider_args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $about_slider_ids,
                );      
          	break;

          	case 'category':
    	        $about_slider_id = array();
		        if ( ! empty( $options['about_us_category_slider'] ) ) {
		            $about_slider_id = $options['about_us_category_slider'];
		        }
		        if( empty( $about_slider_id ) ) {
		        	return;
		        }
		        $about_slider_args = array(
		          	'no_found_rows'  => true,
		          	'cat'   		 => $about_slider_id,
		          	'post_type'      => 'post',
		          	'posts_per_page' => absint( $options['number_of_about_slider'] ),
		        );
          	break;

          	default:
          	break;
        }

        if( ! empty( $about_slider_args ) ) {
            $about_slider_posts = get_posts( $about_slider_args );
        } ?>

        <div class="gallery-slider" data-slick='{ "slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": true, "fade": false, "draggable":false }'>
        <?php if( ! empty( $about_slider_posts ) ) {
            foreach ( $about_slider_posts as $key => $about_slider_post ) {
                $about_slider_post_id = $about_slider_post->ID;
                $img_array = array();
                if ( has_post_thumbnail( $about_slider_post_id ) ) {
                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $about_slider_post->ID ) ,'large' );
                    $img_array[0] = $featured_img[0];
                } else {
                    $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                }
                if ( isset( $img_array ) ) {
                    $about_slider_image['img_array'] = $img_array[0];
                } ?>
            <div class="slider-item" style="background-image:url('<?php echo esc_url( $about_slider_image['img_array'] ); ?>')"></div>
            <?php }
        } ?>        
        </div><!-- .gallery-slider -->
        <?php if( ! empty( $options['gallery_page_link'] ) ) { ?>         
	        <div class="align-center">
	            <a href="<?php echo esc_url( $options['gallery_page_link'] ); ?>" class="more-link fill-black"><?php echo esc_html( $options['gallery_button_text'] ); ?></a>
	        </div>
        <?php }
	}
endif;
add_action( 'yummy_pro_about_us_template_main_slider', 'yummy_pro_about_us_main_slider' );

if ( ! function_exists( 'yummy_pro_about_us_our_team' ) ) :
	/**
	 * Check Our team section 
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_about_us_our_team() {

		$options = yummy_pro_get_theme_options();
		$our_team_content_type = $options['about_us_team_content_type'];
		$our_team_choice_content_type = $options['about_us_choice_content_type'];
		$our_team_advert_content_type = $options['about_us_advert_content_type'];

		switch( $our_team_choice_content_type ) {

		    case 'category':
                $our_choice_id = '';

                if ( ! empty( $options['team_content_category'] ) )
                    $our_choice_id = $options['team_content_category'];

                // Bail if no valid pages are selected.
                if ( ! empty( $our_choice_id ) ) {

	                $our_choice_args = array(
	                  'no_found_rows'  => true,
	                  'cat'            => $our_choice_id,
	                  'post_type'      => 'post',
	                  'posts_per_page' => 3,
	                );
	            }
            break;

            case 'woo-category':
                $our_choice_id = '';

                if ( ! empty( $options['team_content_woo_category'] ) )
                    $our_choice_id = $options['team_content_woo_category'];

                // Bail if no valid pages are selected.
                if ( ! empty( $our_choice_id ) ) {

	                $our_choice_args = array(
	                'post_type'         => 'product',
	                'posts_per_page'    => 3,
	                'tax_query'         => array(
	                    array(
	                        'taxonomy'  => 'product_cat',
	                        'field'     => 'id',
	                        'terms'     => $our_choice_id
	                    )
	                ) );
	            }
            break;

		    default:
		    break;
	    }

		switch( $our_team_content_type ) {
			case 'tp-philosophy-teams':
				$our_team_ids = array();

				if ( ! empty( $options[ 'our_team_slider_tp_posts' ] ) ) {
                    $our_team_ids = ( array ) $options[ 'our_team_slider_tp_posts' ];
                }
                // Bail if no valid pages are selected.
		        if( empty( $our_team_ids ) ) {
		        	return;
		        }
		        $our_team_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'tp-philosophy-teams',
		            'orderby'        => 'post__in',
		            'post__in'       => $our_team_ids,
		        );
		    break;

		    case 'post':
		    	$our_team_ids = array();

				if ( ! empty( $options[ 'our_team_slider_posts' ] ) ) {
                    $our_team_ids = ( array ) $options[ 'our_team_slider_posts' ];
                }
                // Bail if no valid pages are selected.
		        if( empty( $our_team_ids ) ) {
		        	return;
		        }
		        $our_team_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'post',
		            'orderby'        => 'post__in',
		            'post__in'       => $our_team_ids,
		        );
		    break;

		    default:
		    break;
	    }

	    switch( $our_team_advert_content_type ) {
			case 'page':
				$our_team_page_id = array();

				if ( ! empty( $options[ 'our_team_page_id' ] ) ) {
                    $our_team_page_id = $options[ 'our_team_page_id' ];
                }
                // Bail if no valid pages are selected.
		        if( ! empty( $our_team_page_id ) ) {
			        $our_team_advert_args = array(
			            'no_found_rows'  => true,
			            'post_type'      => 'page',
			            'p'       		 => $our_team_page_id,
			        );
			    }
		    break;

		    case 'post':
		    	$our_team_post_id = array();

				if ( ! empty( $options[ 'our_team_post_id' ] ) ) {
                    $our_team_post_id = $options[ 'our_team_post_id' ];
                }
                // Bail if no valid pages are selected.
		        if( ! empty( $our_team_post_id ) ) {
		        	
			        $our_team_advert_args = array(
			            'no_found_rows'  => true,
			            'post_type'      => 'post',
			            'p'       		 => $our_team_post_id,
			        );
			    }
		    break;

		    default:
		    break;
	    }

	    if( ! empty( $our_team_advert_args ) ) {
	    	$our_team_advert_posts = get_posts( $our_team_advert_args );
	    }
	    if( ! empty( $our_choice_args ) ) {
	    	$our_choice_posts = get_posts( $our_choice_args );
	    }
        if( ! empty( $our_team_args ) ) {
            $our_team_posts = get_posts( $our_team_args );
        } ?>

        <section id="our-team" class="page-section no-padding-top col-2">
	        <div class="wrapper">
	            <div class="column-wrapper">
	                <div class="team-decoration">
	                    <div style="background-image:url( '<?php echo get_template_directory_uri().'/assets/uploads/our-team-decoration-01.png'; ?>' )"></div>
	                    <div style="background-image:url( '<?php echo get_template_directory_uri().'/assets/uploads/our-team-decoration-02.png'; ?>' )"></div>
	                </div><!-- .team-decoration -->

	                <?php if ( ! empty( $our_team_advert_posts ) ) {	                
		                foreach ( $our_team_advert_posts as $our_team_advert_post ) { 
		                	$advert_title 	= get_the_title( $our_team_advert_post->ID );
		                	$advert_excerpt = yummy_pro_trim_content( 30, $our_team_advert_post );
		                	?> 
			                <header class="entry-header align-center">
			                    <h2 class="entry-title"><?php echo esc_html( $advert_title ); ?></h2>
			                    <div class="separator"></div>
			                </header>
			                <?php
			                if( ! empty( $advert_excerpt ) ) { ?>
				                <div class="entry-content">
				                    <p><?php echo esc_html( $advert_excerpt ); ?></p>
				                </div><!-- .entry-content -->
			                <?php } 
			            }
			        } 

		            if ( ! empty( $our_choice_posts ) ) { 
	                	$cindex = 1; ?>
				        <div class="our-choice">
				            <h3><?php esc_html_e( 'Our Choice','yummy-pro' ); ?></h3>
	                		<?php foreach ( $our_choice_posts as $our_choice_post ) { 
	                			$choice_url 	= get_the_permalink( $our_choice_post->ID );
	                			$choice_title 	= get_the_title( $our_choice_post->ID );
	                			$choice_excerpt = yummy_pro_trim_content( 10, $our_choice_post );
	                			?>
			                    <div class="choice">
			                        <h4><a href="<?php echo esc_url( $choice_url ); ?>"><?php echo esc_html( $choice_title ); ?></a></h4>
			                        <?php if( ! empty( $choice_excerpt ) ) {
			                        	echo '<p>' . esc_html( $choice_excerpt ) . '</p>';
			                        } ?>
				                    <span class="price">
		                        		<?php if( 'woo-category' == $our_team_choice_content_type ) {   
	                                            $product = new WC_Product( $our_choice_post->ID );
	                                            echo $product->get_price_html();
				                    	} ?>
				                    </span>
			                    </div><!-- .choice -->
	                		<?php $cindex++; 
	                		} ?> 
			        	</div><!-- .our-choice -->
	                <?php } ?>
	            </div><!-- .column-wrapper -->
	        <div class="column-wrapper"> 
	        <?php
	        if( ! empty( $our_team_posts ) ) {
	            $index = 1;
	            foreach ( $our_team_posts as $key => $our_team_post ) {
	                $our_team_post_id = $our_team_post->ID;
	                $img_array = array();
	                if ( has_post_thumbnail( $our_team_post_id ) ) {
	                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $our_team_post->ID ) ,'post-thumbnail' );
	                    $img_array[0] = $featured_img[0];
	                } else {
	                    $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x600.jpg';
	                }
	                if ( isset( $img_array ) ) {
	                    $our_team[$index]['img_array'] = $img_array[0];
	                    $ourteam['imgarray'] = $img_array[0];
	                } 

	                $our_team[$index]['title'] = get_the_title( $our_team_post_id );
	                $our_team[$index]['content'] = yummy_pro_trim_content( 100, $our_team_post );
	                $our_team[$index]['position'] = get_post_meta( $our_team_post_id, 'tp_philosophy_team_designation_value', true );
	                $our_team[$index]['id']   = $our_team_post->ID;
	                
	                $index++;
	                ?>
	            <div class="featured-image" style="background-image:url('<?php echo esc_url( $ourteam['imgarray'] ); ?>')"></div>
	            <?php }
	        }  ?>
	    	</div><!-- .column-wrapper -->
	    	
	    	<?php if( ! empty( $our_team ) ) { ?>
			    <div id="slideshow">
			        <div class="team-slider" data-slick='{ "slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 800, "dots": true, "arrows":true, "autoplay": false, "fade": true, "draggable":false }'>
			        <?php foreach ( $our_team as $team ) { ?>
			            <div class="slider-item" data-thumb="<?php echo esc_url( $team['img_array'] ); ?>">
			                <div class="featured-team-image">
			                    <img src="<?php echo esc_url( $team['img_array'] ); ?>" alt="<?php esc_attr_e( 'Our-team','yummy-pro'); ?>">
			                </div><!-- .featured-image -->
			                <div class="team-slider-contents">
			                    <h2 class="staff-name"><?php echo esc_html( $team['title'] ); ?></h2>
			                    <?php if( ! empty( $team['position'] ) ) { ?> 
			                        <span class="staff-position"><?php echo esc_html( $team['position'] );?></span>
			                    <?php }
			                    if( ! empty( $team['content'] ) ) { ?>
			                    <div class="staff-description">
			                        <p><?php echo esc_html( $team['content'] );?></p>
			                    </div><!-- .staff-description -->
			                    <?php } 
			                    if( 'post' != $our_team_content_type ) {  
			                    	if ( has_action( 'tp_philosophy_tools_team_social_links_action' ) ) {
			                        	do_action( 'tp_philosophy_tools_team_social_links_action', $team['id'] );
			                    	}
				                } ?>
			                </div><!-- .team-slider-contents -->
			            </div><!-- .slider-item -->
			            <?php } ?>
			        </div><!-- .team-slider -->
			        <div class="close-slideshow">
			            <img src="<?php echo get_template_directory_uri() . '/assets/uploads/close-icon.png'; ?>" alt="<?php esc_attr_e( 'Close','yummy-pro'); ?>">
			        </div><!-- .close-slideshow -->
			    </div><!-- #slideshow -->
			<?php } ?>
		</div><!-- .wrapper -->

        <div class="page-decoration">
            <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-03.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
            <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-04.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        </div><!-- .page-decoration -->
    </section><!-- #our-team -->
	<?php }
endif;
add_action( 'yummy_pro_about_us_template_our_team_slider', 'yummy_pro_about_us_our_team' );


if ( ! function_exists( 'yummy_pro_about_us_interior_decoration' ) ) :
	/**
	 * Check about us interior section
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_about_us_interior_decoration() {

		$options = yummy_pro_get_theme_options(); 
		$about_us_interior_content_type = $options['about_us_interior_content_type'];

		switch ( $about_us_interior_content_type ) {
          	
          	case 'page':
                $about_interior_ids = array();
                for ( $i = 1; $i <= 4; $i++ ) {
                    $about_interior_id = null;
                    if ( isset( $options[ 'about_us_interior_page_'.$i ] ) ) {
                        $about_interior_id = $options[ 'about_us_interior_page_'.$i ];
                    }
                    if ( ! empty( $about_interior_id ) ) {
                        $about_interior_ids[] = absint( $about_interior_id );
                    }
                }
                if( empty( $about_interior_ids ) ) {
                	return;
                }
                $about_interior_args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $about_interior_ids,
                );
            break;

            case 'post':
                $about_interior_ids = array();
                for ( $i = 1; $i <= 4; $i++ ) {
                    $about_interior_id = null;
                    if ( isset( $options[ 'about_us_interior_post_'.$i ] ) ) {
                        $about_interior_id = $options[ 'about_us_interior_post_'.$i ];
                    }
                    if ( ! empty( $about_interior_id ) ) {
                        $about_interior_ids[] = absint( $about_interior_id );
                    }
                }
                if( empty( $about_interior_ids ) ) {
                	return;
                }
                $about_interior_args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $about_interior_ids,
                );      
          	break;

          	case 'custom':
          		for ( $i = 1; $i <= 4; $i++ ) {
          			if( ! empty( $options[ 'interior_custom_title_'.$i ] ) ) {
          				$contents[$i]['title'] = $options[ 'interior_custom_title_'.$i ];
          			}
          			if( ! empty( $options[ 'interior_gallery_page_link_'.$i ] ) ) {
          				$contents[$i]['url'] = $options[ 'interior_gallery_page_link_'.$i ];
          			}
          			if( ! empty( $options[ 'interior_custom_image_'.$i ] ) ) {
          				$contents[$i]['img_array'] = $options[ 'interior_custom_image_'.$i ];
          			}
          		}	
    	        
          	break;

          	default:
          	break;
        }
        if ( 'custom' != $about_us_interior_content_type ) {
	      	// Fetch posts.
	      	$about_interior_posts = get_posts( $about_interior_args );

	      	if ( ! empty( $about_interior_posts ) ) {

	          	$i = 1;
	          	foreach ( $about_interior_posts as $key => $about_interior_post ) {
		            $about_interior_post_id = $about_interior_post->ID;

		            $contents[$i]['title']  = get_the_title( $about_interior_post_id );
		            $contents[$i]['url']    = get_the_permalink( $about_interior_post_id );
		            $img_array = array();
		            if ( has_post_thumbnail( $about_interior_post_id ) ) {
                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $about_interior_post->ID ) ,'large' );
                    $img_array[0] = $featured_img[0];
	                } else {
	                    $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
	                }
	                if ( isset( $img_array ) ) {
	                    $contents[$i]['img_array'] = $img_array[0];
	                }
		            $i++;
	          	}
	     	}
	    }
	    for ( $i = 1; $i <= 4; $i++ ) {
		    if( ! empty( $options[ 'interior_gallery_button_text_'.$i ] ) ) {
				$contents[$i]['button_text'] = $options[ 'interior_gallery_button_text_'.$i ];
			}
			if( ! empty( $options[ 'interior_category_title_'.$i ] ) ) {
				$contents[$i]['category_title'] = $options[ 'interior_category_title_'.$i ];
			}
		} 
		if( empty( $contents ) ) {
			return;
		} ?>
		<section id="interior-decoration" class="col-2">
			<div class="center-text">
		        <?php if( !empty( $options['interior_decoration_title'] ) ) { ?>  
		            <h2><?php echo esc_html( $options['interior_decoration_title'] ); ?></h2>
		        <?php }
		        if( !empty( $options['interior_decoration_subtitle'] ) ) { ?>
		            <p><?php echo esc_html( $options['interior_decoration_subtitle'] ); ?></p>
		        <?php } ?>
		    </div><!-- .center-text -->
			<?php foreach ( $contents as $key => $content ) {
				if( ! empty( $content['img_array'] ) ) { ?>
					<article class="hentry column-wrapper" style="background-image:url( '<?php echo esc_url( $content['img_array'] ); ?>' )">
				        <div class="black-overlay"></div>
				        <div class="interior-decoration-content">
				        	<?php if( ! empty( $content['category_title'] ) ) { ?>
				            <div class="interior-decoration-category">
				                <span><?php echo esc_html( $content['category_title'] ); ?></span>
				            </div><!-- interior-decoration-category -->
				            <?php }
				            if( ! empty( $content['title'] ) ) { ?>
				            <header class="entry-header">
				                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
				            </header>
				            <?php }
				            if( ! empty( $content['button_text'] ) && ! empty( $content['url'] ) ) { ?>
				            <div class="align-center">
				                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-transparent"><?php echo esc_html( $content['button_text'] ); ?></a>
				            </div><!-- .align-center -->
				            <?php } ?>
				        </div><!-- .interior-decoration-content -->
				    </article>
				<?php } 
			} ?>
		</section><!-- #interior-decoration -->
	<?php }
endif;
add_action( 'yummy_pro_about_us_template_interior_decoration', 'yummy_pro_about_us_interior_decoration' );


if ( ! function_exists( 'yummy_pro_phone_reservation_section' ) ) :
	/**
	 * Check Our team section 
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function 	yummy_pro_phone_reservation_section() {

		$options = yummy_pro_get_theme_options();
		$reservation_content_type = $options['reservation_content_type'];

	    switch( $reservation_content_type ) {
			case 'page':
				$reservation_page_id = array();

				if ( ! empty( $options[ 'reservation_page_id' ] ) ) {
                    $reservation_page_id = $options[ 'reservation_page_id' ];
                }
                // Bail if no valid pages are selected.
                if( empty( $reservation_page_id ) ) {
                	return;
                }
		        $reservation_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'page',
		            'p'       		 => $reservation_page_id,
		        );
		    break;

		    case 'post':
		    	$reservation_post_id = array();

				if ( ! empty( $options[ 'reservation_post_id' ] ) ) {
                    $reservation_post_id = $options[ 'reservation_post_id' ];
                }
                // Bail if no valid pages are selected.
                if( empty( $reservation_post_id ) ) {
                	return;
                }		        	
		        $reservation_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'post',
		            'p'       		 => $reservation_post_id,
		        );
		    break;

		    default:
		    break;
	    }

	    if( ! empty( $reservation_args ) ) {
	    	$reservation_posts = new WP_Query( $reservation_args );
	    }
	    if ( $reservation_posts->have_posts() ) {

			while ( $reservation_posts->have_posts() ) {

				$reservation_posts->the_post();
	    		?>
		        <section id="reserveby-phone" class="page-section no-padding-top">
				    <div class="wrapper">
				        <div class="booking-details">
				            <img class="phone" src="<?php echo get_template_directory_uri().'/assets/uploads/phone.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
				            <img class="call" src="<?php echo get_template_directory_uri().'/assets/uploads/call.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
				             
					                <header class="entry-header">
					                    <h2 class="entry-title"><?php the_title(); ?></h2>
					                    <div class="separator"></div>
					                </header><!--.entry-header-->
					                <?php
					                $phone_reservation_content = get_the_content();
					                if( ! empty( $phone_reservation_content ) ) { ?>
					                <div class="entry-content">
					                    <p><?php echo wp_kses_post( $phone_reservation_content ); ?></p>
					                </div><!-- .entry-content -->
					                <?php } ?>
				        </div><!--.booking-details-->
				    </div><!--.wrapper--> 
				    <div class="page-decoration">
				        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-01.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
				    </div><!-- .page-decoration -->
				</section><!--reserved-phone-->
            <?php }
        } ?>
	<?php }
endif;
add_action( 'yummy_pro_phone_reservation_section_hook', 'yummy_pro_phone_reservation_section' );

if ( ! function_exists( 'yummy_pro_reservation_memorable_section' ) ) :
	/**
	 * Check Our team section 
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_reservation_memorable_section() {

		$options = yummy_pro_get_theme_options();
		$reservation_content_type = $options['memorable_reservation_type'];
		$memorable_header_content_type = $options['reservation_header_type'];

		switch( $memorable_header_content_type ) {
			case 'custom':
                $content['header'][0]['title'] = ! empty( $options['reservation_header_title'] ) ? $options['reservation_header_title'] : '';
                $content['header'][0]['img']   = ! empty( $options['reservation_header_image'] ) ? $options['reservation_header_image'] : get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                $content['header'][0]['url']   = ! empty( $options['reservation_header_link'] ) ? $options['reservation_header_link'] : '#';
            break;

            case 'page' :
                $id = ( ! empty( $options['reservation_header_page'] ) ) ? absint( $options['reservation_header_page'] ) : '';
                if( ! empty ( $id ) ) {
                $args = array( 
	                    'post_type' => 'page',
	                    'page_id'   => $id,
	                 );
	            }
	            if( ! empty ( $args ) ) {
	                $posts = get_posts( $args );
	                foreach ( $posts as $post ) {
	                    $img_array = null;
	                    if ( has_post_thumbnail( $post->ID ) ) {
	                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
	                    } else {
	                        $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
	                    }

	                    $content['header'][1]['title'] = get_the_title( $post->ID );
	                    $content['header'][1]['url']   = get_the_permalink( $post->ID );
	                    $content['header'][1]['img']   = $img_array[0];
	                }
	            }
            break;

		    default:
		    break;
	    }

	    switch( $reservation_content_type ) {
			case 'category':
				$reservation_id = '';

				if ( ! empty( $options[ 'reservation_memorable_category' ] ) ) {
                    $reservation_id = $options[ 'reservation_memorable_category' ];
                }
                // Bail if no valid pages are selected.
                if( empty( $reservation_id ) ) {
                	return;
                }
		        $memorable_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'post',
		            'posts_per_page' => 3,
		            'cat'			 => $reservation_id,
		        );
		    break;

		    case 'post':
		    	$reservation_post_ids = array();

				if ( ! empty( $options[ 'reservation_memorable_post_ids' ] ) ) {
                    $reservation_post_ids = ( array ) $options[ 'reservation_memorable_post_ids' ];
                }
                // Bail if no valid pages are selected.
                if( empty( $reservation_post_ids ) ) {
                	return;
                }		        	
		        $memorable_args = array(
		            'no_found_rows'  => true,
		            'post_type'      => 'post',
		            'posts_per_page' => 3,
		            'post__in'       => $reservation_post_ids,
		        );
		    break;

		    default:
		    break;
	    }
	    if( ! empty( $memorable_args ) ) {

	    	$memorable_posts = get_posts( $memorable_args );
            $i = 1;
            foreach ( $memorable_posts as $memorable_post ) :
                $page_id = $memorable_post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                	if( $i == 3 ){
                    	$img_array      = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'large' );
                	}
                	else {
                		$img_array      = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'post-thumbnail' );
                	}
                } else {
                	if( $i == 3 ){
                    	$img_array[0]       = get_template_directory_uri() . '/assets/uploads/no-featured-image-600x600.jpg';
                    	$img_array[1]       = 600;
                    	$img_array[2]       = 600;
                	}
                	else {
                		$img_array[0]       = get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
                		$img_array[1]       = 300;
                    	$img_array[2]       = 300;
                	}
                    	
                }
                $content['content'][$i]['title']        = get_the_title( $page_id );
                $content['content'][$i]['url']          = get_the_permalink( $page_id );
                $content['content'][$i]['excerpt']      = yummy_pro_trim_content( 20, $memorable_post );
                $content['content'][$i]['img_array']    = $img_array;

                $i++;
            endforeach;
	    } 
	    if ( ! empty( $content['header'] ) ) {
	    	foreach ( $content['header'] as $header ) { ?>
		      	<section id="memorable-day" class="parallax" style="background-image:url( '<?php echo esc_url( $header['img'] ); ?>' );" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="-500">
		        	<div class="black-overlay"></div>
		        	<div class="wrapper">
		          		<header class="entry-header">
		            		<h2 class="entry-title color-white"><a href="<?php echo esc_url( $header['url'] ); ?>"><?php echo esc_html( $header['title']); ?></a></h2>
		          		</header>
		        	</div><!--.wrapper-->
		      	</section><!-- #memorable-day -->
		    <?php }
		}
		if ( ! empty( $content['content'] ) ) {
		$index = 1; ?>
      	<section id="food-item" class="page-section pass no-padding-top col-2 memorable-night">
        	<div class="wrapper">
          		<div class="row no-margin add-shadow">
	            	<div class="column-wrapper">
	    			<?php foreach ( $content['content'] as $content ) { 
	    				if( $index == 3 ) {
	    					$addclass = 'full-width';
	    				}
	    				else {
	    					$addclass = 'clear';
	    				} ?>
		              	<article class="hentry has-post-thumbnail <?php echo $addclass; ?>">
		                	<div class="featured-image">
		                  		<a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" width="<?php echo absint( $content['img_array'][1] ); ?>" height="<?php echo absint( $content['img_array'][2] ); ?>"></a>
		                  		<?php if( $index == 3 ) {
		                  			echo '<div class="black-overlay"></div>';
		                  		} ?>
		                	</div><!--.featured-image-->
			                <div class="entry-summary">
			                	<div class="entry-excerpt">
				                  	<h4 class="color-black"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
				                  	<?php if( ! empty( $content['excerpt'] ) ) {
				                  		echo '<p>' . esc_html( $content['excerpt'] ) . '</p>';
				                  	} ?>
				                </div><!--.entry-excerpt-->
			                </div><!--.entry-summary-->
		              	</article><!--.hentry has-post-thumbnail-->
		            <?php if( $index == 2 ) { ?>
		            </div><!--.column-wrapper-->
		            <div class="column-wrapper">
		            <?php } $index++; } ?>
		            </div><!--.column-wrapper-->
			    </div><!--.row-->
	        </div><!--.wrapper-->
	        <div class="page-decoration">
	          	<img src="<?php echo get_template_directory_uri() . '/assets/uploads/dish-03.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        		<img src="<?php echo get_template_directory_uri() . '/assets/uploads/dish-04.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
	        </div><!-- .page-decoration -->
      	</section><!--#food-item-->
	<?php } }
endif;
add_action( 'yummy_pro_reservation_memorable_section_hook', 'yummy_pro_reservation_memorable_section' );


/*************** MENU PAGE *********************/

if ( ! function_exists( 'yummy_pro_menu_page_first_section' ) ) :
	/**
	 * menu page first section.
	 *
	 * @since yummy Pro 1.0
	 */
	function yummy_pro_menu_page_first_section() {
		$options = yummy_pro_get_theme_options(); 

		$content_type = $options['menu_first_section_content_type'];
		$args = array();
		$cat_id = '';
		switch ( $content_type ) {
			case 'category':
				$cat_id = ! empty( $options['menu_first_section_content_category'] ) ?$options['menu_first_section_content_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'post',
						'cat'		=> $cat_id,
						'posts_per_page' => 12,
						);
				endif;
			break;

			case 'woo-category':
				$cat_id = ! empty( $options['menu_first_section_content_woo_category'] ) ?$options['menu_first_section_content_woo_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'product',
						'posts_per_page' => 12,
						'tax_query'	=> array(
							array(
								'taxonomy'  => 'product_cat',
					            'field'     => 'id',
					            'terms'     => $cat_id,
							) ),
						);
				endif;
			break;
		}

		if ( empty( $args ) ) {
			return;
		}

		$posts = get_posts( $args );
		?>
		<section id="todays-menu" class="page-section today-menu-list">
			<div class="wrapper">
				<?php if ( ! empty( $options['menu_first_section_title'] ) ) : ?>
					<header class="entry-header align-center">	
						<h2 class="entry-title entry-title-separator"><?php echo esc_html( $options['menu_first_section_title'] ); ?></h2>
					</header><!-- .entry-header -->
				<?php endif; ?>

				<div class="entry-content">
					<div class="food-item-list clear">
						<div class="list-items">
							<div class="food-item-list-wrapper">
								<?php foreach( $posts as $post ) : ?>
									<div class="menu-list">
										<h5><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h5>
										<p><?php echo esc_html( yummy_pro_trim_content( 10, $post ) ); ?></p>
										<?php 
										$tag = ( $content_type == 'woo-category' ) ? 'product_tag' : 'post_tag';
										$tags = get_the_terms( $post->ID, $tag ); 
										if ( ! empty( $tags ) ) :
											foreach ( $tags as $tag ) : ?>
												<a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>" class="more-link small-btn order-item"><?php echo esc_html( $tag->name ); ?></a>
											<?php endforeach;
										endif; 
										if ( $content_type == 'woo-category' ) : ?>
											<span class="price">
												<?php  
			                                    $product = new WC_Product( $post->ID );
			                                    echo $product->get_price_html();
			                                    ?>
											</span>
										<?php endif; ?>
									</div><!--.menu-list-->
								<?php endforeach; ?>
							</div><!-- .food-item-list-wrapper -->
						</div><!-- .list-items -->
					</div><!-- .food-item-list -->
				</div><!-- .entry-content -->
			</div><!-- .wrapper -->

			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-01.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-02.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
			</div><!-- .page-decoration -->
		</section><!-- #todays-menu -->
	<?php }
endif;
add_action( 'yummy_pro_menu_page_action', 'yummy_pro_menu_page_first_section', 10 );

if ( ! function_exists( 'yummy_pro_menu_page_second_section' ) ) :
	/**
	 * menu page second section.
	 *
	 * @since yummy Pro 1.0
	 */
	function yummy_pro_menu_page_second_section() {
		$options = yummy_pro_get_theme_options(); 
		$header_background = ! empty( $options['menu_second_section_image'] ) ? $options['menu_second_section_image'] : get_template_directory_uri() . '/assets/uploads/breakfast.jpg';
		$header_title = ! empty( $options['menu_second_section_title'] ) ? $options['menu_second_section_title'] : '';
		$content_type = $options['menu_second_section_content_type'];
		$args = array();
		$cat_id = '';
		switch ( $content_type ) {
			case 'category':
				$cat_id = ! empty( $options['menu_second_section_content_category'] ) ?$options['menu_second_section_content_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'post',
						'cat'		=> $cat_id,
						'posts_per_page' => 8,
						);
				endif;
			break;

			case 'woo-category':
				$cat_id = ! empty( $options['menu_second_section_content_woo_category'] ) ?$options['menu_second_section_content_woo_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'product',
						'posts_per_page' => 8,
						'tax_query'	=> array(
							array(
								'taxonomy'  => 'product_cat',
					            'field'     => 'id',
					            'terms'     => $cat_id,
							) ),
						);
				endif;
			break;
		}

		if ( empty( $args ) ) {
			return;
		}

		$posts = get_posts( $args );
		?>
		<section id="breakfast-cover" class="parallax" style="background-image:url('<?php echo esc_url( $header_background ); ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
			<div class="black-overlay"></div>
			<div class="wrapper">
				<?php if ( ! empty( $header_title ) ) : ?>
					<header class="entry-header">
						<h2 class="entry-title color-white"><?php echo esc_html( $header_title ); ?></h2>
					</header>
				<?php endif; ?>
			</div><!--.wrapper-->
		</section><!-- #breakfast-cover -->

		<section id="breakfast" class="col-2 food-item">
			<div class="wrapper">
				<div class="breakfast-item add-shadow">
					<div class="row no-margin">
						<?php 
						$i = 1;
						foreach ( $posts as $post ) : ?>
							<div class="column-wrapper">
								<div class="recipe-list">
									<h4 class="color-black"><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h4>
									<p><?php echo esc_html( yummy_pro_trim_content( 8, $post ) ); ?></p>
									<?php if ( 'woo-category' == $content_type ) : ?>
										<span><?php esc_html_e( 'Price', 'yummy-pro' ); ?> <span class="price">
											<?php  
		                                    $product = new WC_Product( $post->ID );
		                                    echo $product->get_price_html();
		                                    ?>
										</span></span>
									<?php endif; 
									$tag = ( $content_type == 'woo-category' ) ? 'product_tag' : 'post_tag';
									$tags = get_the_terms( $post->ID, $tag ); 
									if ( ! empty( $tags ) ) :
										foreach ( $tags as $tag ) : ?>
											<a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>" class="more-link small-btn"><?php echo esc_html( $tag->name ); ?></a>
										<?php endforeach;
									endif; 
									?>
								</div><!--.recipe-list-->
								<div class="featured-image">
									<?php  
									if ( has_post_thumbnail( $post->ID ) ) {
										$image_url = get_the_post_thumbnail_url( $post->ID, 'post-thumbnail' );
									} else {
										$image_url = get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
									}
									?>
									<a href="<?php the_permalink( $post->ID ); ?>"><img src="<?php echo esc_url( $image_url ); ?>"></a>
								</div><!--.featured-image-->
							</div><!--.column-wrapper-->
							<?php if ( $i % 2 == 0 ) : ?>
								</div>
								<div class="row no-margin">
							<?php endif;
							$i++;
						endforeach; ?>
					</div><!--.row-->
				</div><!--.breakfast-item-->
			</div><!-- .wrapper -->

			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-03.jpg" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-04.jpg" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
			</div><!-- .page-decoration -->
		</section><!-- #breakfast -->
	<?php }
endif;
add_action( 'yummy_pro_menu_page_action', 'yummy_pro_menu_page_second_section', 20 );

if ( ! function_exists( 'yummy_pro_menu_page_third_section' ) ) :
	/**
	 * menu page third section.
	 *
	 * @since yummy Pro 1.0
	 */
	function yummy_pro_menu_page_third_section() {
		$options = yummy_pro_get_theme_options(); 
		$header_background = ! empty( $options['menu_third_section_image'] ) ? $options['menu_third_section_image'] : get_template_directory_uri() . '/assets/uploads/lunch.jpg';
		$header_title = ! empty( $options['menu_third_section_title'] ) ? $options['menu_third_section_title'] : '';
		$header_subtitle = ! empty( $options['menu_third_section_sub_title'] ) ? $options['menu_third_section_sub_title'] : '';
		$content_type = $options['menu_third_section_content_type'];
		$args = array();
		$cat_id = '';
		switch ( $content_type ) {
			case 'category':
				$cat_id = ! empty( $options['menu_third_section_content_category'] ) ?$options['menu_third_section_content_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'post',
						'cat'		=> $cat_id,
						'posts_per_page' => 12,
						);
				endif;
			break;

			case 'woo-category':
				$cat_id = ! empty( $options['menu_third_section_content_woo_category'] ) ?$options['menu_third_section_content_woo_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'product',
						'posts_per_page' => 12,
						'tax_query'	=> array(
							array(
								'taxonomy'  => 'product_cat',
					            'field'     => 'id',
					            'terms'     => $cat_id,
							) ),
						);
				endif;
			break;
		}

		if ( empty( $args ) ) {
			return;
		}

		$posts = get_posts( $args );
		?>
		<section id="lunch-cover" class="parallax" style="background-image:url('<?php echo esc_url( $header_background ); ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
			<div class="black-overlay"></div>
			<div class="wrapper">
				<?php if ( ! empty( $header_title ) ) : ?>
					<header class="entry-header">
						<h2 class="entry-title color-white"><?php echo esc_html( $header_title ); ?></h2>
					</header>
				<?php endif; ?>
			</div><!--.wrapper-->
		</section><!-- #lunch-cover -->

		<section id="lunch">
			<div class="wrapper">
				<div class="lunch-details add-shadow">
					<img class="fruit" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/fruit-1.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
					<img class="fruit-1" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/fruit.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
					<?php if ( ! empty( $header_subtitle ) ) : ?>
						<header class="entry-header">
							<h2 class="entry-title"><?php echo esc_html( $header_subtitle ); ?></h2>
							<div class="separator"></div>
						</header><!--.entry-header-->
					<?php endif; ?>

					<div class="entry-content col-2 food-item">
						<?php foreach ( $posts as $post ) : ?>
							<div class="lunch-menu">
								<h5 class="color-black"><a href="<?php echo the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h5>
								<?php  
								$tag = ( $content_type == 'woo-category' ) ? 'product_tag' : 'post_tag';
								$tags = get_the_terms( $post->ID, $tag ); 
								if ( ! empty( $tags ) ) :
									foreach ( $tags as $tag ) : ?>
										<a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>" class="more-link small-btn"><?php echo esc_html( $tag->name ); ?></a>
									<?php endforeach;
								endif; 
								?>
								<p><?php echo esc_html( yummy_pro_trim_content( 14, $post ) ); ?></p>
								<?php if ( 'woo-category' == $content_type ) : ?>
									<span><?php esc_html_e( 'Price', 'yummy-pro' ); ?> <span class="price">
										<?php  
	                                    $product = new WC_Product( $post->ID );
	                                    echo $product->get_price_html();
	                                    ?>
									</span></span>
								<?php endif; ?>
							</div><!--.lunch-menu-->
						<?php endforeach; ?>
					</div><!-- .entry-content -->
				</div><!--.lunch-details-->
			</div><!--.wrapper-->

			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-05.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-06.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
			</div><!-- .page-decoration -->
		</section><!-- #lunch -->
	<?php }
endif;
add_action( 'yummy_pro_menu_page_action', 'yummy_pro_menu_page_third_section', 30 );

if ( ! function_exists( 'yummy_pro_menu_page_fourth_section' ) ) :
	/**
	 * menu page forth section.
	 *
	 * @since yummy Pro 1.0
	 */
	function yummy_pro_menu_page_fourth_section() {
		$options = yummy_pro_get_theme_options(); 
		$header_background = ! empty( $options['menu_forth_section_image'] ) ? $options['menu_forth_section_image'] : get_template_directory_uri() . '/assets/uploads/dinner.jpg';
		$header_title = ! empty( $options['menu_forth_section_title'] ) ? $options['menu_forth_section_title'] : '';
		$content_type = $options['menu_forth_section_content_type'];
		$args = array();
		$cat_id = '';
		switch ( $content_type ) {
			case 'category':
				$cat_id = ! empty( $options['menu_forth_section_content_category'] ) ?$options['menu_forth_section_content_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'post',
						'cat'		=> $cat_id,
						'posts_per_page' => 12,
						);
				endif;
			break;

			case 'woo-category':
				$cat_id = ! empty( $options['menu_forth_section_content_woo_category'] ) ?$options['menu_forth_section_content_woo_category'] : '';
				if ( ! empty( $cat_id ) ) :
					$args = array(
						'post_type'	=> 'product',
						'posts_per_page' => 12,
						'tax_query'	=> array(
							array(
								'taxonomy'  => 'product_cat',
					            'field'     => 'id',
					            'terms'     => $cat_id,
							) ),
						);
				endif;
			break;
		}

		if ( empty( $args ) ) {
			return;
		}

		$posts = get_posts( $args );
		?>
		<section id="dinner-cover" class="parallax" style="background-image:url('<?php echo esc_url( $header_background ); ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
			<div class="black-overlay"></div>
			<div class="wrapper">
				<?php if ( ! empty( $header_title ) ) : ?>
					<header class="entry-header">
						<h2 class="entry-title color-white"><?php echo esc_html( $header_title ); ?></h2>
					</header>
				<?php endif; ?>
			</div><!--.wrapper-->
		</section><!-- #dinner-cover -->
		<section id="todays-menu" class="page-section today-menu-list dinner-menu-items">
			<div class="wrapper">
				<div class="entry-content">
					<div class="food-item-list clear">
						<div class="list-items">
							<div class="food-item-list-wrapper">
								<?php foreach( $posts as $post ) : ?>
									<div class="menu-list">
										<h5><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h5>
										<p><?php echo esc_html( yummy_pro_trim_content( 10, $post ) ); ?></p>
										<?php 
										$tag = ( $content_type == 'woo-category' ) ? 'product_tag' : 'post_tag';
										$tags = get_the_terms( $post->ID, $tag ); 
										if ( ! empty( $tags ) ) :
											foreach ( $tags as $tag ) : ?>
												<a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>" class="more-link small-btn order-item"><?php echo esc_html( $tag->name ); ?></a>
											<?php endforeach;
										endif; 
										if ( $content_type == 'woo-category' ) : ?>
											<span class="price">
												<?php  
			                                    $product = new WC_Product( $post->ID );
			                                    echo $product->get_price_html();
			                                    ?>
											</span>
										<?php endif; ?>
									</div><!--.menu-list-->
								<?php endforeach; ?>
							</div><!-- .food-item-list-wrapper -->
						</div><!-- .list-items -->
					</div><!-- .food-item-list -->
				</div><!-- .entry-content -->
			</div><!-- .wrapper -->

			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-07.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-08.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
			</div><!-- .page-decoration -->
		</section><!-- #todays-menu -->
	<?php }
endif;
add_action( 'yummy_pro_menu_page_action', 'yummy_pro_menu_page_fourth_section', 40 );

if ( ! function_exists( 'yummy_pro_menu_page_fifth_section' ) ) :
	/**
	 * menu page fifth section.
	 *
	 * @since yummy Pro 1.3
	 */
	function yummy_pro_menu_page_fifth_section() {
		$options = yummy_pro_get_theme_options(); 
		$header_background = ! empty( $options['menu_fifth_section_image'] ) ? $options['menu_fifth_section_image'] : get_template_directory_uri() . '/assets/uploads/drinks.jpg';
		$header_title = ! empty( $options['menu_fifth_section_title'] ) ? $options['menu_fifth_section_title'] : '';
		$content_type = $options['menu_fifth_section_content_type'];
		$args = array();
		$cat_id = '';
		switch ( $content_type ) {
			case 'category':
				$cat_ids = array();
	            if ( !empty( $options['menu_fifth_section_content_category'] ) ) {
	                $cat_ids = $options['menu_fifth_section_content_category'];
	            }
	            
				if ( ! empty( $cat_ids ) ) :
					foreach( $cat_ids as $cat_id ) :
						$args[] = array(
							'post_type'		=> 'post',
							'cat'			=> $cat_id,
							'posts_per_page'=> 8,
						);
					endforeach;
				endif;
			break;

			case 'woo-category':
				$cat_ids = array();
	            if ( !empty( $options['menu_fifth_section_content_woo_category'] ) ) {
	                $cat_ids = $options['menu_fifth_section_content_woo_category'];
	            }
				if ( ! empty( $cat_ids ) ) :
					foreach( $cat_ids as $cat_id ) :
					$args[] = array(
						'post_type'	=> 'product',
						'posts_per_page' => 8,
						'tax_query'	=> array(
							array(
								'taxonomy'  => 'product_cat',
					            'field'     => 'id',
					            'terms'     => $cat_id,
							) ),
						);
					endforeach;
				endif;
			break;
		}

		if ( empty( $args ) ) {
			return;
		}
		?>
		<section id="drink-cover" class="parallax" style="background-image:url('<?php echo esc_url( $header_background ); ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
			<div class="black-overlay"></div>
			<div class="wrapper">
				<?php if ( ! empty( $header_title ) ) : ?>
					<header class="entry-header">
						<h2 class="entry-title color-white"><?php echo esc_html( $header_title ); ?></h2>
					</header>
				<?php endif; ?>
			</div><!--.wrapper-->
		</section><!-- #drink-cover -->
		<section id="drinks-content" class="food-item page-section">
        	<div class="wrapper">
          		<div class="col-2">
					<div class="column-wrapper">
						<div class="drink-menu">
							<img class="nuts" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/nuts.png" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>"> 
							<img class="nuts-1" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/nuts-1.png" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>"> 
							<img class="flower" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/flower.png" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>"> 
							<img class="flower-1" src="<?php echo get_template_directory_uri(); ?>/assets/uploads/flower-1.png" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>"> 							
							<?php 
							$fifth_menu_page_title = $options['fifth_section_title'];
							$fifth_menu_page_subtitle = $options['fifth_section_subtitle'];

							if( ! empty( $fifth_menu_page_title ) || ! empty( $fifth_menu_page_subtitle ) ) : ?>
			                    <header class="entry-header">
			                        <?php if ( ! empty( $fifth_menu_page_title ) ) : ?>
			                            <h2 class="entry-title"><?php echo esc_html( $fifth_menu_page_title ); ?></h2>
			                        <?php endif; 
			                        if ( ! empty( $fifth_menu_page_subtitle ) ) : ?>
			                            <p class="title-desc"><?php echo esc_html( $fifth_menu_page_subtitle ); ?></p>
			                        <?php endif; ?>
			                    </header><!-- .entry-header -->
			                <?php endif; ?>        
							<div class="entry-content" style="background-image:url('<?php echo get_template_directory_uri() .'/assets/uploads/drink-menu.png'; ?>');">
								<?php if( 'category' == $options['menu_fifth_section_content_type'] ) {

									$fifth_menu_categories_id = ! empty( $options['menu_fifth_section_content_category'] ) ? $options['menu_fifth_section_content_category'] : ''; 
	                				$fifth_menu_categories_id = ! empty( $fifth_menu_categories_id ) ? $fifth_menu_categories_id : array(); ?>
	                				<ul class="nav-tabs">
										<?php foreach ( $fifth_menu_categories_id as $key => $category_id ) {
			                            	$category_object = get_category( $category_id );
			                            	echo '<li><a href="#'. esc_attr( $category_object->slug ) .'">'. esc_html( $category_object->name ) .'</a></li>';
			                        	} ?>
									</ul>
								<?php } else {
									$fifth_menu_categories_id = ! empty( $options['menu_fifth_section_content_woo_category'] ) ? $options['menu_fifth_section_content_woo_category'] : ''; 
	                				$fifth_menu_categories_id = ! empty( $fifth_menu_categories_id ) ? $fifth_menu_categories_id : array(); ?>
	                				<ul class="nav-tabs">
										<?php 
										$zindex = 1;
										foreach ( $fifth_menu_categories_id as $key => $category_id ) {
			                            	$category_object = get_term_by( 'id', $category_id, 'product_cat', '' );
			                            	$active_class = ( 1 == $zindex ) ? 'active' : '';
			                            	$zindex++;
			                            	echo '<li class="' . esc_attr( $active_class ) . '"><a href="#'. esc_attr( $category_object->slug ) .'">'. esc_html( $category_object->name ) .'</a></li>';
			                        	} ?>
									</ul>
								<?php }	?>								
							</div><!--.entry-content-->
						</div><!--.drink-menu-->
					</div><!--.column-wrapper-->
					<?php $index = 0; ?>
					<div class="column-wrapper">
              			<div class="drink-list">
	              		<?php foreach ( $args as $arg ) : 
							$add_class_active = ( 0 === $index ) ? 'active' : ''; ?>
		              		<div id="<?php echo esc_attr( yummy_pro_cat_slug( $cat_ids[$index] ) ) ?>" class="tab-pane <?php echo esc_attr( $add_class_active ); ?>">
	              				<?php $posts = get_posts( $arg );
		              			foreach ( $posts as $post ) { ?>
		              				<div class="post-content">
					                    <div class="image-wrapper">
					                    	<a href="<?php the_permalink( $post->ID ); ?>">
					                    	<?php if ( has_post_thumbnail( $post->ID ) ) {
												$image_url = get_the_post_thumbnail_url( $post->ID, 'thumbnail' );
											} else {
												$image_url = get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
											} ?>
					                    	<img src="<?php echo esc_url( $image_url ); ?>"></a>
					                    </div><!--.image-wrapper-->
					                    <div class="drinks-content">
					                    	<h5 class="color-black"><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h5>
					                    	<?php $tag = ( $content_type == 'woo-category' ) ? 'product_tag' : 'post_tag';
												$tags = get_the_terms( $post->ID, $tag ); 
												if ( ! empty( $tags ) ) :
													foreach ( $tags as $tag ) : ?>
														<a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>" class="more-link small-btn order-item"><?php echo esc_html( $tag->name ); ?></a>
													<?php endforeach;
												endif;
											?> 										
					                    	<span><?php esc_html_e( 'From','yummy-pro' ); 
					                    	if ( $content_type == 'woo-category' ) : ?>
												<span class="price">
													<?php  
				                                    $product = new WC_Product( $post->ID );
				                                    echo $product->get_price_html();
				                                    ?>
												</span>
											<?php endif; ?>
											</span>
					                    </div>
				                  	</div><!--.post-content-->
		              			<?php } ?>
	              			</div><!-- #coffee -->					
	              		<?php $index++;	endforeach; ?>
						</div><!--.drink-list-->
            		</div><!--.column-wrapper-->
          		</div><!--.col-2-->
        	</div><!--.wrapper-->   

			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-09.jpg" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/menu-dish-10.jpg" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
			</div><!-- .page-decoration -->
		</section><!-- #todays-menu -->
	<?php }
endif;
add_action( 'yummy_pro_menu_page_action', 'yummy_pro_menu_page_fifth_section', 50 );

if ( ! function_exists( 'yummy_pro_cat_slug' ) ) :
	/**
	 * menu page fifth section category slug
	 *
	 * @since yummy Pro 1.3
	 */
	function yummy_pro_cat_slug( $id = '' ) {

		$options = yummy_pro_get_theme_options();
		if( 'woo-category' == $options['menu_fifth_section_content_type'] ) {
			$category_object = get_term_by( 'id', $id, 'product_cat', '' );
		} else {
			$category_object = get_category( $id );
		} 
		return $category_object->slug;
	}
endif;